@@ -35,6 +35,7 @@ enum {
   PROP_TOKEN,
   PROP_TOKEN_SECRET,
   PROP_SIGNATURE_HOST,
+  PROP_SIGNATURE_METHOD,
 };
 
 static RestProxyCall *
@@ -71,6 +72,9 @@ oauth_proxy_get_property (GObject *object, guint property_id,
   case PROP_SIGNATURE_HOST:
     g_value_set_string (value, priv->signature_host);
     break;
+  case PROP_SIGNATURE_METHOD:
+    g_value_set_enum (value, priv->method);
+    break;
   default:
     G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
   }
@@ -108,6 +112,9 @@ oauth_proxy_set_property (GObject *object, guint property_id,
       g_free (priv->signature_host);
     priv->signature_host = g_value_dup_string (value);
     break;
+  case PROP_SIGNATURE_METHOD:
+    priv->method = g_value_get_enum (value);
+    break;
   default:
     G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
   }
@@ -182,7 +189,13 @@ oauth_proxy_class_init (OAuthProxyClass *klass)
                                    PROP_SIGNATURE_HOST,
                                    pspec);
 
-  /* TODO: add enum property for signature method */
+  pspec = g_param_spec_enum ("signature-method", "signature-method",
+                             "Signature method used",
+                             OAUTH_TYPE_SIGNATURE_METHOD, HMAC_SHA1,
+                             G_PARAM_READWRITE|G_PARAM_STATIC_STRINGS);
+  g_object_class_install_property (object_class,
+                                   PROP_SIGNATURE_METHOD,
+                                   pspec);
 }
 
 static void
@@ -775,3 +788,21 @@ oauth_proxy_new_echo_proxy (OAuthProxy  *proxy,
 
   return (RestProxy *)echo_proxy;
 }
+
+GType
+oauth_signature_method_get_type (void)
+{
+  static GType enum_type_id = 0;
+  if (G_UNLIKELY (!enum_type_id))
+  {
+    static const GEnumValue values[] =
+    {
+      { PLAINTEXT, "PLAINTEXT", "plaintext" },
+      { HMAC_SHA1, "HMAC_SHA1", "hmac-sha1" },
+      { 0, NULL, NULL }
+    };
+    enum_type_id = g_enum_register_static ("OAuthSignatureMethod", values);
+  }
+  return enum_type_id;
+}
+
